Struct GridSequence

pub struct GridSequence<const W: usize, const H: usize> {
    pub framerate: NonZeroU8,
    pub font_scale: FontSize,
    /* private fields */
}

Fields

framerate: NonZeroU8font_scale: FontSize

Implementations

Source

impl<const W: usize, const H: usize> GridSequence<W, H>

pub fn new(s: impl Into<FontSize>) -> Self

pub fn prepend(&mut self, frame: Frame<W, H>)

push a frame to the beginning of the sequence

pub fn append(&mut self, frame: Frame<W, H>)

push a frame to the end of the sequence

pub fn glyph_set(&self) -> &HashSet<char>